veloxml.tree package
====================

Submodules
----------

veloxml.tree.decision\_tree\_classification module
--------------------------------------------------

.. automodule:: veloxml.tree.decision_tree_classification
   :members:
   :show-inheritance:
   :undoc-members:

veloxml.tree.random\_forest\_classification module
--------------------------------------------------

.. automodule:: veloxml.tree.random_forest_classification
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: veloxml.tree
   :members:
   :show-inheritance:
   :undoc-members:
